Lab 1 Task 2 example code

Dependencies:   mbed m3pi

Fork of 3pi_Lab1_Task2_Example1 by Craig Evans

Revision:
2:b135039705fe
Parent:
1:3143ad629ed8
--- a/main.cpp	Thu Jun 22 13:18:32 2017 +0000
+++ b/main.cpp	Thu Jun 29 09:38:49 2017 +0000
@@ -1,4 +1,4 @@
-/* 3pi Example 2
+/* 3pi Lab 1 Example 2
 
 (c) Dr Craig A. Evans, University of Leeds
 
@@ -23,11 +23,12 @@
     
     // move cursor to position (0,0) - top-left
     robot.lcd_goto_xy(0,0);
-    // print on the LCD - the number 5 is the number of characters in the string
-    robot.lcd_print("Ex. 2",5);
+    robot.lcd_print("Lab 1",5); // 5 is number of characters in message (max 8)
+    robot.lcd_goto_xy(0,1);
+    robot.lcd_print("Task 2",6);
     
-    // we will update the motors 50 times per second
-    float dt = 1.0/50.0;
+    // we will update the motors 100 times per second
+    float dt = 1.0/100.0;
 
     // main loop - this runs forever
     while(1) {